% COEFFX Calculates the coefficients of the finite difference expression of heat equation
%        with T derivatives with respect to x computed at time p+1

% Script component of TEMSPOL: a MATLAB thermal model for deep subduction
% zones including major phase transformations.
% A.M. Negredo, J.L. Valera and E. Carminati (2002)

 R=1+Lt/Cp*betat(i,j);
 Ex=K/(rho(i,j)*Cp*Dx^2);
A=-R/(2*Dx)*vx(i,j)-Ex;
B=R/Dt+2*Ex;
C=R/(2*Dx)*vx(i,j)-Ex;
 Dx1=R/Dt*T(i,j)-R*vz(i,j)/(2*Dz)*(T(i,j+1)-T(i,j-1));
 Dx2=K/(rho(i,j)*Cp*Dz^2)*(T(i,j+1)-2*T(i,j)+T(i,j-1));
 Dx3=-vz(i,j)*(Lt/Cp*betaz(i,j)+alpha*g*(T(i,j)+273)/Cp)+H(i,j)/(rho(i,j)*Cp)+tau(i,j)*abs(Vs)/(W*rho(i,j)*Cp);
D=Dx1+Dx2+Dx3;
%We do not need to save the values of Ex,R,Dx1,Dx2 and Dx3 because they are recalculated every temporal iteration.
clear Ex R Dx1 Dx2 Dx3;

