% INIT_VELO calculates the initial velocity field
%	This script creates a [vx, vz] matrix containing the horizontal and
%   vertical components of the initial velocity of all grid nodes.

% String component of TEMSPOL: a MATLAB thermal model for deep subduction
% zones including major phase transformations.
% A.M. Negredo, J.L. Valera and E. Carminati (2002)

% x0 and za are the coordinates of the corner point at which the base of the 
%   slab turns to subduct into the mantle

x2=x1-L*cot(dip)*(1-cos(dip));
x0=x2+L*sin(dip);
za=depth-L;         % Depth of the base of the lithosphere
c=za+x0*cot(dip);   % Constant that will be later used in velo.m

% initial x-coordinates of the tip of the base (x3) and top (x4) of the slab
%   (later used in velo.m) 

x3=x0;
x4=x3-L*sin(dip);

% setting the initial values for vx and vy to simplify calculations.

vx(1:I,1:J)=0;
vz(1:I,1:J)=0;
 
% Start calculations
jlit=round(za/Dz+1);    % j-index of node that defines the base of the lithosphere
for j=jlit:J
    z(j)=(j-1)*Dz;
    for i=1:I
        x(i)=(i-1)*Dx;
% equation of the front of the slab at time=0 (z1)
        z1=-cot(dip)*x(i)+za+cot(dip)*x0;
% equation of the top of the slab (z2)
        z2=tan(dip)*x(i)+za+L-tan(dip)*x1;

% velocity definition at lithospheric depths
    	if z(j)>=za & x(i)>x0
                vx(i,j)=Vs;
        end
% zone of the slab corner x4<=x<=x0
    	if x(i)>=x4 & x(i)<=x0 
	        if z(j)>=z1 & z(j)<=z2
                costheta=(z(j)-za)/sqrt((x0-x(i))^2+(z(j)-za)^2);
                sintheta=(x0-x(i))/sqrt((x0-x(i))^2+(z(j)-za)^2);
                vx(i,j)=Vs*costheta;
                vz(i,j)=Vs*sintheta;
            end       
        end        
    end
end

clear costheta sintheta z1 z2 z3 z4;